@@ -1,11 +1,11 @@
 import logging
+from django.contrib import messages
 from django.shortcuts import get_object_or_404
 from django.utils.translation import gettext_lazy as _
+from django.views import View
 
-from django.contrib import messages
 from process.conf import get_conf
 from .generic_views import (
-    View,
     ProcessSecurity,
     ProcessGenericListView,
     ProcessGenericDeleteView
